Welcome to SFR’s documentation! — SFR 0.1.3 documentation

# Welcome to SFR’s documentation!

Contents:

- Introduction
  - Motivation
  - Limitations
- components package
  - Submodules
  - components.config module
  - components.connectors module
  - components.containers module
  - components.exceptions module
  - components.handlers module
  - components.loggers module
  - Module contents
- src
  - components package
  - main module

# Indices and tables

- Index

- Module Index

- Search Page